core.match_filter.template
--------------------------

.. currentmodule:: eqcorrscan.core.match_filter.template
.. automodule:: eqcorrscan.core.match_filter.template

    .. comment to end block

    Classes
    -------
    .. toctree::
        :maxdepth: 1

        core.match_filter.template.Template

    Functions
    ---------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       read_template

    .. comment to end block